summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/262intf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/262intf.cpp')
-rw-r--r--src/devices/sound/262intf.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/devices/sound/262intf.cpp b/src/devices/sound/262intf.cpp
index 0a76cdf6d2b..616cefc6377 100644
--- a/src/devices/sound/262intf.cpp
+++ b/src/devices/sound/262intf.cpp
@@ -50,12 +50,12 @@ void ymf262_device::timer_handler(int c, const attotime &period)
//-------------------------------------------------
// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------
-void ymf262_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
+void ymf262_device::sound_stream_update(sound_stream &stream, std::vector<read_stream_view> const &inputs, std::vector<write_stream_view> &outputs)
{
- ymf262_update_one(m_chip, outputs, samples);
+ ymf262_update_one(m_chip, outputs);
}
//-------------------------------------------------
@@ -81,7 +81,7 @@ void ymf262_device::device_start()
if (!m_chip)
throw emu_fatalerror("ymf262_device(%s): Error creating YMF262 chip", tag());
- m_stream = stream_alloc_legacy(0,4,rate);
+ m_stream = stream_alloc(0,4,rate);
/* YMF262 setup */
ymf262_set_timer_handler (m_chip, &ymf262_device::static_timer_handler, this);
@@ -50,12 +50,12 @@ void ymf262_device::timer_handler(int c, const attotime &period)
//-------------------------------------------------
-// sound_stream_update_legacy - handle a stream update
+// sound_stream_update - handle a stream update
//-------------------------------------------------